<?php
/**
 * Plugin Name: SEO ALT EDITOR 
 * Description: Seo Alt Editor est un plugin WordPress qui permet de gérer facilement les balises ALT des images de votre médiathèque. Retrouvez-le dans les <a href="options-general.php?page=seo-alt-editor">réglages</a>
 * Version: 1.1
 * Author: <a href="https://www.encoreplusnet.com/">Encoreplusnet.com</a>
 */

// Sécurité : Empêcher l'accès direct au fichier
if (!defined('ABSPATH')) {
    exit;
}

// Ajouter une page de réglages
function seo_alt_editor_menu() {
    add_options_page('SEO ALT Editor', 'SEO ALT Editor', 'manage_options', 'seo-alt-editor', 'seo_alt_editor_page');
}
add_action('admin_menu', 'seo_alt_editor_menu');

// Affichage de la page
function seo_alt_editor_page() {
    ?>
    <div class="wrap">
        <h1>SEO ALT Editor</h1>
        <p>Une balise ALT bien rédigée doit être concise, descriptive et contenir des mots-clés pertinents, 
            sans dépasser 16-20 mots pour assurer une indexation optimale par Google.<br/> 
            Décrivez précisément l'image. Intégrez des mots-clés pertinents et évitez le bourrage de mots-clés. </p>
        <select id="seo-alt-filter">
            <option value="all">Toutes les images de votre Médiathèque</option>
            <option value="filled">Avec la balise ALT</option>
            <option value="empty">Sans la balise ALT</option>
        </select>
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th style="width: 30%;">Image</th>
                    <th style="width: 70%;">Balise ALT</th>
                </tr>
            </thead>
            <tbody id="seo-alt-editor-table">
                <?php
                $args = array(
                    'post_type'      => 'attachment',
                    'post_status'    => 'inherit',
                    'posts_per_page' => -1,
                    'post_mime_type' => 'image',
                );
                $images = get_posts($args);
                foreach ($images as $image) {
                    $alt_text = get_post_meta($image->ID, '_wp_attachment_image_alt', true);
                    echo '<tr class="seo-alt-row" data-alt="' . (!empty($alt_text) ? 'filled' : 'empty') . '">
                            <td><img src="' . wp_get_attachment_thumb_url($image->ID) . '" width="100"></td>
                            <td>
                                <textarea data-id="' . $image->ID . '" class="seo-alt-editor-textarea" rows="2" cols="100">' . esc_textarea($alt_text) . '</textarea>
                            </td>
                          </tr>';
                }
                ?>
            </tbody>
        </table>
    </div>
    <?php
}

// Ajouter le script JS pour AJAX
function seo_alt_editor_scripts($hook) {
    if ($hook !== 'settings_page_seo-alt-editor') {
        return;
    }
    wp_enqueue_script('seo-alt-editor', plugin_dir_url(__FILE__) . 'seo-alt-editor.js', array('jquery'), null, true);
    wp_localize_script('seo-alt-editor', 'seoAltEditor', array('ajax_url' => admin_url('admin-ajax.php')));
}
add_action('admin_enqueue_scripts', 'seo_alt_editor_scripts');

// Gérer la mise à jour de la balise ALT
function seo_alt_editor_update_alt() {
    if (!isset($_POST['image_id']) || !isset($_POST['alt_text'])) {
        wp_send_json_error('Données manquantes.');
    }
    
    $image_id = intval($_POST['image_id']);
    $alt_text = sanitize_text_field($_POST['alt_text']);
    
    if (update_post_meta($image_id, '_wp_attachment_image_alt', $alt_text)) {
        wp_send_json_success('Balise ALT mise à jour.');
    } else {
        wp_send_json_error('Échec de la mise à jour.');
    }
}
add_action('wp_ajax_seo_alt_editor_update_alt', 'seo_alt_editor_update_alt');