jQuery(document).ready(function($) {
    // Filtrage des images selon l'option sélectionnée
    $('#seo-alt-filter').on('change', function() {
        let filter = $(this).val();
        $('.seo-alt-row').each(function() {
            let altStatus = $(this).data('alt');
            if (filter === 'all' || filter === altStatus) {
                $(this).show();
            } else {
                $(this).hide();
            }
        });
    });

    $('.seo-alt-editor-textarea').on('input', function() {
        let textarea = $(this);
        let imageId = textarea.data('id');
        let altText = textarea.val();

        // Vérification si imageId est bien défini
        if (!imageId) {
            console.error("ID de l'image non défini !");
            return;
        }

        $.ajax({
            type: 'POST',
            url: seoAltEditor.ajax_url,
            data: {
                action: 'seo_alt_editor_update_alt',
                image_id: imageId,
                alt_text: altText,
            },
            success: function(response) {
                if (response.success) {
                    showTooltip(textarea, 'Mise à jour réussie', '#4CAF50');
                } else {
                    showTooltip(textarea, 'Erreur de mise à jour', '#FF5733');
                }
            },
            error: function() {
                showTooltip(textarea, 'Erreur AJAX', '#FF5733');
            }
        });
    });

    // Fonction pour afficher un tooltip temporaire
    function showTooltip(element, message, bgColor) {
        let tooltip = $('<div class="seo-tooltip"></div>').text(message);

        tooltip.css({
            position: 'absolute',
            background: bgColor,
            color: '#fff',
            padding: '5px',
            borderRadius: '5px',
            top: element.offset().top - 30,
            left: element.offset().left,
            zIndex: 1000
        });

        $('body').append(tooltip);

        setTimeout(function() {
            tooltip.fadeOut(500, function() {
                $(this).remove();
            });
        }, 1500);
    }
});
